leaftools.list_prolated_durations_of_leaves_in_expr
===================================================

.. autofunction:: abjad.tools.leaftools.list_prolated_durations_of_leaves_in_expr.list_prolated_durations_of_leaves_in_expr
